# Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.

import threading

import tqdm


class DownloadProgressBar:
    """
    Thread-safe progress bar for tracking downloads.
    """

    def __init__(self, total_size_bytes: int):
        self.__tqdm = tqdm.tqdm(
            # Uses size in bits since most people know their internet bandwidth in
            # Megabits/sec
            total=total_size_bytes * 8,
            unit="b",
            unit_scale=True,
            unit_divisor=1000 * 1000,
        )
        self.__lock = threading.Lock()

    def update(self, num_bytes: int) -> None:
        with self.__lock:
            self.__tqdm.update(n=num_bytes * 8)



#!/usr/bin/env python3
# Copyright (c) Meta Platforms, Inc. and affiliates. All Rights Reserved.

from setuptools import find_packages, setup

setup(
    name="ego4d",
    version="1.2",
    author="FAIR",
    author_email='info@ego4d-data.org',
    description="Ego4D Dataset CLI",
    url="https://github.com/facebookresearch/Ego4d/",
    install_requires=[
        "boto3",
        "tqdm",
        # "av",
        # "torch",
        # "torchvision",
        # "pytorch_lightning",
        # "matplotlib",
        # "simplejson",
        # "matplotlib",
        # "pandas",
    ],
    tests_require=[
        "pytest",
        "moto",
    ],
    packages=['ego4d', 'ego4d.cli'],
    # packages=find_packages("ego4d/cli", exclude=["features", "tests"]),
    entry_points={
        'console_scripts': ['ego4d=ego4d.cli.cli:main'],
    }
)
